﻿using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;

using Lassalle.Flow;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            CreateDiagram(this.addFlow);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 다이어그램 생성하기 - CreateDiagram(addFlow)

        /// <summary>
        /// 다이어그램 생성하기
        /// </summary>
        /// <param name="addFlow">AddFlow</param>
        private void CreateDiagram(AddFlow addFlow)
        {
            addFlow.PageUnit = GraphicsUnit.Point;
            addFlow.PinSize  = 8;

            addFlow.NodeModel.FillColor = Color.LightYellow;
            addFlow.NodeModel.Pins      = new List<PointF>
            {
                new Point(0  , 50 ),
                new Point(50 , 0  ),
                new Point(100, 50 ),
                new Point(50 , 100)
            };
            addFlow.NodeModel.Font      = new Font("Calibri", 14);

            addFlow.LinkModel.LineStyle = LineStyle.Orthogonal;
            addFlow.LinkModel.DrawColor = Color.Navy;

            // 2개 노드들을 생성한다.
            // 모든 노드를 위한 디폴트에 의해 정의된 것처럼 첫번째 2개 노드들은 4개의 핀들을 갖고 있다.
            // 그러나 세번째 노드는 3개의 핀들만 갖고 있다.
            Node node1 = new Node(100, 30 , 80, 80, "4 핀", addFlow);
            Node node2 = new Node(400, 250, 80, 80, "4 핀", addFlow);
            Node node3 = new Node(400, 30 , 80, 80, "3 핀", addFlow);

            node3.Pins = new List<PointF> { new Point(0, 50), new Point(100, 50), new Point(50, 100) };

            addFlow.AddNode(node1);
            addFlow.AddNode(node2);
            addFlow.AddNode(node3);

            // 1개의 링크를 생성한다.
            this.AddLink(addFlow, node1, node2, 2, 0);
        }

        #endregion
        #region 링크 추가하기 - AddLink(addFlow, startNode, endNode, startPinIndex, endPinIndex)

        /// <summary>
        /// 링크 추가하기
        /// </summary>
        /// <param name="addFlow">AddFlow</param>
        /// <param name="startNode">시작 노드</param>
        /// <param name="endNode">종료 노드</param>
        /// <param name="startPinIndex">시작 핀 인덱스</param>
        /// <param name="endPinIndex">종료 핀 인덱스</param>
        /// <returns>링크</returns>
        private Link AddLink(AddFlow addFlow, Node startNode, Node endNode, int startPinIndex, int endPinIndex)
        {
            Link link = new Link(startNode, endNode, startPinIndex, endPinIndex, "", addFlow);

            addFlow.AddLink(link);

            return link;
        }

        #endregion
    }
}